/**
 * Copyright (c) 2006-2012 EBM WebSourcing, 2012-2015 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.bc.mail;

import javax.jbi.JBIException;

import org.ow2.petals.bc.mail.listeners.ExternalListener;
import org.ow2.petals.bc.mail.listeners.JBIListener;
import org.ow2.petals.component.framework.bc.AbstractBindingComponent;

/**
 * The Mail Binding Component.
 * <p>
 * It creates some sub components like :
 * <p>
 * the <b>{@link MailSessionManager}</b> used to manage session with mail
 * servers : create and open sessions, send and receive mails,
 * <p>
 * the <b>{@link MimeMessageManager}</b> used to process (reading or creating)
 * mail messages,
 * <p>
 * the <b>{@link SessionDescriptorBuilder}</b> used to extract information from
 * a Mail URI String,
 * <p>
 * the <b>{@link ExternalListener}</b> used to manage listeners for
 * external mail addresses registered during SU deployment,
 * <p>
 * the <b>{@link JBIListener}</b> used to process incoming JBI messages
 * <p>
 * This class defines some Default Value for mail features like :
 * <p>
 * <b>SMTP</b> (25), <b>IMAP</b> (143) and <b>POP3</b> (110) default ports,
 * <p>
 * default mail folder (INBOX),
 * <p>
 * default mail checking period (60 seconds).
 * 
 * @author Olivier Fabre - EBM WebSourcing
 */
public class MailComponent extends AbstractBindingComponent {

    protected MailSessionManager mailSessionManager;

    protected MimeMessageManager mimeMessageManager;

    @Override
    protected void doInit() throws JBIException {
        this.mimeMessageManager = new MimeMessageManager(this.getLogger());
        this.mailSessionManager = new MailSessionManager(this.getLogger());
    }

    public MailSessionManager getMailSessionManager() {
        return this.mailSessionManager;
    }

    public MimeMessageManager getMimeMessageManager() {
        return this.mimeMessageManager;
    }
}
