/**
 * Copyright (c) 2006-2012 EBM WebSourcing, 2012-2015 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.bc.mail.service.provide;

import org.ow2.petals.bc.mail.MailConstants;

import com.ebmwebsourcing.easycommons.lang.StringHelper;

/**
 * This descriptor handles information used to connect to a mail server to read or send emails.
 * @author Adrien LOUIS - EBM WebSourcing
 * @author Olivier Fabre - EBM WebSourcing
 */
public class ProvideDescriptor {

    /**
     * Used for both smtp, imap and pop3 scheme
     */
    private String scheme;

    /**
     * Used for both smtp, imap and pop3 scheme
     */
    private String hostname;

    /**
     * Used for both smtp, imap and pop3 scheme
     */
    private String port;

    /**
     * Used for both smtp, imap and pop3 scheme
     */
    private String username;

    /**
     * Used for both smtp, imap and pop3 scheme
     */
    private String password;

    /**
     * Used only for smtp scheme
     */
    private String fromAddress;

    /**
     * ReplyTo
     */
    private String replyAddress;

    /**
     * Used only for smtp scheme
     */
    private String toAddress;

    /**
     * Subject
     */
    private String subject;

    /**
     * HELO host name (mail.smtp.localhost)
     */
    private String heloHost;

    /**
     * Send either the source, the attachments or both of the payload. Default
     * value is : content-and-attachments.
     */
    private String sendMode;

    /**
     * Specify the mime content-type for the created email
     */
    private String contentType;

    public String getScheme() {
        return scheme;
    }

    public void setScheme(String scheme) {
        if (StringHelper.isNullOrEmpty(scheme)) {
            scheme = MailConstants.MAIL_SCHEME_SMTP;
        }
        this.scheme = scheme;
    }

    public String getHostname() {
        return hostname;
    }

    public void setHostname(String hostname) {
        this.hostname = hostname;
    }

    public String getPort() {
        return port;
    }

    public void setPort(String port) {
        if (StringHelper.isNullOrEmpty(port)) {
            port = MailConstants.MAIL_SMTP_PORT_DEFAULT;
        }
        this.port = port;
    }

    public String getUsername() {
        return username;
    }

    public void setUsername(String username) {
        this.username = username;
    }

    public String getPassword() {
        return password;
    }

    public void setPassword(String password) {
        this.password = password;
    }

    public String getFromAddress() {
        return fromAddress;
    }

    public void setFromAddress(String fromAddress) {
        this.fromAddress = fromAddress;
    }

    public String getReplyAddress() {
        return replyAddress;
    }

    public void setReplyAddress(String replyAddress) {
        this.replyAddress = replyAddress;
    }

    public String getToAddress() {
        return toAddress;
    }

    public void setToAddress(String toAddress) {
        this.toAddress = toAddress;
    }

    public String getSubject() {
        return subject;
    }

    public void setSubject(String subject) {
        this.subject = subject;
    }

    public String getHeloHost() {
        return heloHost;
    }

    public void setHeloHost(String heloHost) {
        this.heloHost = heloHost;
    }

    public String getSendMode() {
        return sendMode;
    }

    public void setSendMode(String sendMode) {
        if (StringHelper.isNullOrEmpty(sendMode)) {
            sendMode = MailConstants.SEND_MODE_CONTENTATTACHMENTS;
        }
        this.sendMode = sendMode;
    }

    public String getContentType() {
        return contentType;
    }

    public void setContentType(String contentType) {
        if (StringHelper.isNullOrEmpty(contentType)) {
            contentType = "text/plain";
        }
        this.contentType = contentType;
    }
}
